pub enum BasicPalette {
Hot,
Mem,
Io,
Red,
Green,
Blue,
Aqua,
Yellow,
Purple,
Orange,
}Expand description
A plain color palette in which the color is not chosen based on function semantics.
Exactly how the color is chosen depends on a number of other configuration options like
[super::Options.consistent_palette] and [super::Options.hash]. In the absence of options
like that, these palettes all choose colors randomly from the indicated spectrum, and does not
consider the name of the frame’s function when doing so.
Variants
Hot
A palette in which colors are chosen from a red-yellow spectrum.
Mem
A palette in which colors are chosen from a green-blue spectrum.
Io
A palette in which colors are chosen from a wide blue spectrum.
Red
A palette in which colors are chosen from a red spectrum.
Green
A palette in which colors are chosen from a green spectrum.
Blue
A palette in which colors are chosen from a blue spectrum.
Aqua
A palette in which colors are chosen from an aqua-tinted spectrum.
Yellow
A palette in which colors are chosen from a yellow spectrum.
Purple
A palette in which colors are chosen from a purple spectrum.
Orange
A palette in which colors are chosen from a orange spectrum.