pub struct FuncFrameAttrsMap(/* private fields */);Expand description
Provides a way to customize the attributes on the SVG elements for a frame.
Implementations
Sourceimpl FuncFrameAttrsMap
impl FuncFrameAttrsMap
Sourcepub fn from_file(path: &Path) -> Result<FuncFrameAttrsMap, Error>
pub fn from_file(path: &Path) -> Result<FuncFrameAttrsMap, Error>
Parse frame attributes from a file.
Each line should consist of a function name, a tab (\t), and then a sequence of
tab-separated name=value pairs.
Sourcepub fn from_reader<R>(reader: R) -> Result<FuncFrameAttrsMap, Error>where
R: BufRead,
pub fn from_reader<R>(reader: R) -> Result<FuncFrameAttrsMap, Error>where
R: BufRead,
Parse frame attributes from a BufRead.
Each line should consist of a function name, a tab (\t), and then a sequence of
tab-separated name=value pairs.